#!/bin/sh
#
# bb-prtdiag.sh: Sun Enterprise Server check - BB external script test
#
# version 2.0
# version 2.1 - now checks for failures, faults listed in $TEST output
#               as well as bad fans, power supplies, front lights, etc
# version 2.2 - works for E450 now, not just 3500-6500 class
# version 2.3 - works for E250 now.
# version 2.4 - properly uses $CAT instead of cat
# version 2.5 - properly uses $MACHINE instead of `uname -n` in bb-hosts check
# version 2.6 - properly uses $MACHINE instead of $MACHINE due to fqdn
#                 using comma in name - thanks Craig Cook
# version 3.0 - updates to work properly with BB 1.6
# version 3.1 - updates to redirect prtdiag to temp file then cat temp file,
#                 prtdiag only execs one time
# version 3.2 - combined bb-temperature.sh to bb-prtdiag.sh to enhance
#                 temperature monitoring
#               added code to display any warn or panic conditions at
#                 beginning of display ala bb-disk.sh or bb-sybase_ASE.sh
# version 3.3 - corrected temperature check for E450 usage
#               added list of servers not to check temperatures
#               as well as showing a color in a warning line, set that color
#                 for the whole page
#               removed requirement for prtdiag to be listed against
#                 every host in bb-hosts
#               Applied Todd Jimenez style get_header and get_footer functions
#               added check for bsys.local vars being set
#               cosmetic changes to make code easier to read
#               Applied patch from Jon Diekema
# version 3.4 - fixed typo "Mimimum" to "Minimum"
# version 3.5 - Added "UltraAX-i2 Sun-Blade-100" to EXCLUDE_SYSTEMS
#                 as suggested by Mike Arnold
# version 3.6 - removed Sun-Blade-100 from EXCLUDE_SYSTEMS
#               Show prtdiag option in header
#               removed $MACHINE from error messages
#               simplified LED check as suggested by Bryan Banister
#               added code from "temperature.sh" v2.2 as enhanced by
#                 Tom Schmidt
#               added check for CUT to be defined
#               added PRTDIAG_IGNORE_ERRORS
#               restored functionality to check for the existence of "prtdiag"
#                 after the server name in bb-hosts, but now optional
#               changed &red and &yellow to variables
# version 3.7 - applied patch supplied from Axel Apitz
#               - added support for 280R and V880
#             - replaced LEDFILE_SECONDROW with LEDFILE_SECONDROW
# version 3.8 - applied patch supplied from Ash Martin
#               - properly uses $CP instead of cp
#               - added functionality to test 280R's and V880's
#             - added UltraSPARC-IIi-cEngine to EXCLUDE_SYSTEMS
#             - applied changes from Christian Thibodeau
# version 3.9 - applied patch supplied from Patrick Van Acker
#               - 280R with one CPU was not reporting correct temp
#               Fixed patch from Patrick - it didn't work
#               TEMPS=`$SED -n ${TEMPLINE}p $PRTDIAGOUTPUT | $AWK '{
#               to:
#               TEMPS=`$CAT $PRTFILE | $SED -n ${TEMPLINE}p | $AWK '{
#             - applied patch supplied from Christopher White
#               - Updated with V480R changes
#             - applied patch posted to deadcat
#               - fixes for Sun Blade 100
#        4.0  - rewrote using procedures
#               - now easier to disable temperature check if 
#                 using temperature.sh (maintained by Tom Schmidt)
#             - Added debug code to allow input from a text file
#               - bundled with example prtdiag output for each
#                   hardware platform
#             - Made fault test a variable PRTDIAG_IGNORE_FAULTS
#             - Corrected Sun Fire 3800 test
#             - Added Netra T4 support
#             - Updated 3500/4500 support
#               - Additional checks for Fan and Power
#             - Added patch from Axel Apitz
#               - removed "Fan Speed" lines from checks
#             - Added check for Available boards on Sun-Fire with help
#                 from Rick McClinton
#             - Changed "$CAT $PRTFILE | $AWK ..." to
#                       "$AWK ... $PRTFILE" 
#                 thanks to Thomas R Brand
#             - Temperature check section was broken, RS="," did not work
#             - Added Patch from Christian Thibodeau
#               - Added V240 support
#             - Added patch from Frank Fegert
#               - Added V100 support
#        4.1  - Added "Status        Fault" to PRTDIAG_IGNORE_FAULTS
#                 thanks to Glenn Barbee
#             - Corrected typo for 
#               if [ "$PRTDIAG_IGNORE_FAULTS" = "" ]; then
#             - Corrected false power supply alarm for E250's with 
#                 only one supply.
#             - Added patch posted to deadcat for V210
#             - Adjusted Temperature thresholds for V880, 280R based on
#               "prtpicl -v -c temperature-sensor"
#       4.2   - Added "Fan Fail|Temp Fail" to PRTDIAG_IGNORE_ERRORS
#                 Reason: SF480R - false alarm: prtdiag reports some failures!!!
#       4.3   - Removed "Fan Fail|Temp Fail" since it did not work - could also
#               be a genuine error that would be ignored on other models
#             - Added section for Sun Fire 480R power supply checks - previous
#               versions did not detect a power supply failure
#             - Applied patch from Eric van de Meerakker
#               - lom command output has changed for V100's
#               - Changed Voltage check
#             - Applied patch from Christian Thibodeau
#               - Added rudimentary support for V1280
#       4.4   - Applied patch from Joerg Melzig
#               - Added support for V890
#       4.5   - Added disk checks for 480R
#             - Corrected activity LED checks for E250 & E450
#             - Added more debug code
#             - Modified to allow passing of parameters for testing
#             - Applied patch from Kelvin Russell
#               - Corrected 480R fan checks
#       4.6   - Applied patch from Christian Thibodeau
#               - Added support for V440
#             - Applied patch from Ricardo Stella
#               - Added power supply and disk led check for V440 
#               - Added support for Netra X1
#             - Applied patch from Richard Hall
#               - Moved check_defaults_set two lines earlier
#               - Added support for E3000
#             - Modified voltage check for V240
#             - Modified temperature check for V240 & V440
#             - Modified fan check for V440
#       4.7   - Applied patch from Uwe Kirbach
#               - Added support for Fujitsu-Siemens GP7000F and
#                 PrimePower 200, 400, 600, 1000, 250, 450, 650, 850
#               - Fix: for Sun Fire [346]800 check also for CPU types US-III+
#               - Fix: typo (missing backtick) in temperature capturing for Sun-Fire-V2[14]0
#               - Fix: in output conversion for temperature
#                      END clause should have at least an empty block or can be omited
#             - Applied patch from Richard Hall
#               - Disabled activity checks for E450 & E250
#       4.8   - Applied patch from Uwe Kirbach
#                 The main difference is:
#                 lines 402-426 (#No Temperature...) have
#                 to be moved inside the
#                  check for FSC machines (case $MACHINETYPE in GPU* ...)
#                 Also some minor changes for FSC machines
#       4.9   - Applied patch from Joerg Melzig
#                 Added support for Sun Fire 490
#             - Applied patch from Christian Thibodeau
#                 Re-enable temperature checks for V210, V240, and V440
#                 Added extra test to handle later OBP versions on V210
#                  only reporting "okay" for temperature
#       4.10  - Updated CPU temps for Ultra-250 based on information
#                 from Chris Greenman
#       4.11  - Removed extra "}" in the check_temp_status section
#             - Removed low temperature checks
#             - Rewrote sunfire Active Boards check
#             - Added Temperature and Fan checks for Ultra 25
#             - Added install instructions for Hobbitmon
#       4.12  - Changed disabled boards check for 4800
#                updated Sun-Fire temperature checks
#                added support for Sun Blade 150,1500,2500 temperature checks
#                 based on code from Tom Schmidt
#                changed temperature checks to use procedures
#                added voltage and hard disk checks for v240
#       4.13  - Changed temperature check for 210 & 240
#                 now looks for non "okay" status
#               Added support for T2000
#               Updated temperature check for v1280/E2900
#               Increased default temperature thresholds for Netra-T12
#	4.14  - Added >> $REDLINE output redirects for all CATCH_COMMANDS
#		Fixed broken grep for word "ail" which would trigger on the words "Memory Available" and thus
#		  alert RED
#		Added $MACHINE and $MACHINEDOTS hardcoded because hobbit doesn't always pass these correctly
#		Changed definitions file to work with hobbit also instead of only bbdef.sh
#		Hardcoded PRTDIAG_COMMAND 
#
# BIG BROTHER / XXXXXXXXXXXXXXXX status
#
# Written by Paul A. Luzzi
#  on March 22, 2000
#
# 3.0  Updates by David Levin           3 Jan 2001
# 3.1  Updates by Guy Thibodeau        24 Jan 2001
# 3.3  Updates by Craig Cook           22 Sep 2001
# 3.4  Updates by Craig Cook           28 Sep 2001
# 3.5  Updates by Craig Cook           22 Oct 2001
# 3.6  Updates by Craig Cook           12 Nov 2001
# 3.7  Updates by Craig Cook           21 May 2002
# 3.8  Updates by Craig Cook           12 Aug 2002
# 3.9  Updates by Craig Cook           27 Nov 2002
# 4.0  Updates by Craig Cook           24 Jul 2003
# 4.1  Updates by Craig Cook            2 Sep 2003
# 4.2  Updates by Thomas Hoerndlein    21 Jan 2004
# 4.3  Updates by Craig Cook            6 Feb 2004
# 4.4  Updates by Craig Cook           24 Jan 2005
# 4.5  Updates by Craig Cook           24 Feb 2005
# 4.6  Updates by Craig Cook            8 Mar 2005
# 4.7  Updates by Craig Cook            3 Jun 2005
# 4.8  Updates by Craig Cook           17 Jan 2007
# 4.9  Updates by Craig Cook           24 Jan 2007
# 4.10 Updates by Craig Cook            5 Mar 2007
# 4.11 Updates by Craig Cook            8 Mar 2008
# 4.12 Updates by Craig Cook           21 May 2008
# 4.13 Updates by Craig Cook           21 Nov 2008
# 4.13 Updates by Tom Moore            10 Jun 2009
#
# Provided by www.cookitservices.com

#########################################################################
# NOTE
# This has been tested with BB 1.9e
#
# Tested on
#   Sun Solaris (Will probably only run on Solaris! ;-)
#
# For BB testing, pass the filename with "prtdiag -v" output and machinetype
#
#   ./bb-prtdiag.sh ./280r Sun-Fire-280R
#
# Check the "types" file located with this package for settings
#
# If you have a E450 that "blinks" refer to sun document "18490"
# If you have a 250 that is missing prtdiag information check that
#    you have the 'E250 supplement' installed with patch 106504-01.
#
#########################################################################

########################################
# INSTALLATION - Big Brother
#  Step 1  - Update bb-bbexttab to include this bb-prtdiag.sh
#            (older BB versions update EXT section of the bbdef.sh script)
#
#  Step 2 - Copy lines mentioned to bbsys.local (without the #'s)
#
#  Step 3 - If you are using an older version of BB without bb-bbexttab
#             and you don't want this run on every client uncomment
#             CHECK_BB_HOSTS="Y" and add the name of this $TEST to
#             bb-hosts for this client. eg.
#             myserver.domain.com   # prtdiag
#
#  Step 4 - Restart Big Brother
#
# INSTALLATION - Hobbitmon
#
# Step 1 - Copy this script to $HOBBITCLIENT/ext/bb-prtdiag.sh
#          Ensure your hobbit user owns the script and is executable (chown)
#
# Step 2 - Add the lines mentioned in the bbsys.local section to
#             $HOBBITCLIENT/etc/hobbitclient.cfg
#           Note: You may have to hard code the
#                 PLATFORM_SPEC & PRTDIAG_COMMAND variables, or 
#                 do not enter it in hobbitclient.cfg
#                 You may also need to use /usr/xpg4/bin/awk or /usr/bin/nawk
#
# Step 3 - Add this:
#
#          [prtdiag]
#                  ENVFILE $HOBBITCLIENTHOME/etc/hobbitclient.cfg
#                  CMD $HOBBITCLIENTHOME/ext/bb-prtdiag.sh
#                  LOGFILE $HOBBITCLIENTHOME/logs/bb-prtdiag.log
#                  INTERVAL 5
#
#          to $HOBBITCLIENT/etc/clientlaunch.cfg
#
# You do not need to restart hobbit to activate
#
# NOTE - The TEST variable in the configuration section, this is the name used
#        as the column header and in the bb-hosts file.
########################################

##################################
# CONFIGURE IT HERE
##################################
TEST="prtdiag"
BBPROG="$0"; export BBPROG

# If you use temperature.sh, change this to N
CHECK_TEMPERATURE=Y

ENV_CHECK=1 # Check environmental settings 1 = on, anything else = off

#
# Start of lines to put in bbsys.local
#
UNAME="/usr/local/bin/uname"
MACHINE=`$UNAME -n`
MACHINEDOTS=`$UNAME -n`
PLATFORM_SPEC=`$UNAME -i`
PRTDIAG_COMMAND="/usr/platform/$PLATFORM_SPEC/sbin/prtdiag"
# or
#PRTDIAG_COMMAND="$SUDO /usr/platform/$PLATFORM_SPEC/sbin/prtdiag"
#PRTDIAG_OPT="-v"
#Systems that don't support temperature checks
#EXCLUDE_SYSTEMS="Ultra-1 Ultra-2 Ultra-5_10 Ultra-30 Ultra-60 Ultra-80 UltraAX-i2 UltraSPARC-IIi-cEngine Sun-Fire Netra-T4 UltraAX-e2 Ultra-Enterprise-10000"
#PRTDIAG_IGNORE_ERRORS="No failures|Most recent AC Power Failure|Minimum Available|CS Fail|No Hardware failures|^===|currently no Boards|Fault     Fan"
#PRTDIAG_IGNORE_FAULTS="No Recent System Faults found|No System Faults found|Fault Value|Fault LED|NO_FAULT|Power  Fault|Status        Fault|Fault           off"
#LOM_COMMAND="/usr/sbin/lom"
#LOM_OPT="-pfvt"

#export UNAME PLATFORM_SPEC PRTDIAG_COMMAND PRTDIAG_OPT 
#export PRTDIAG_IGNORE_ERRORS PRTDIAG_IGNORE_FAULTS

# If you use a version of BB older than 1.7b3 you will need
#   the following lines (CUT was added to base 1.7b3)
#CUT="/usr/bin/cut"
#export CUT

#
# End of lines to put in bbsys.local
#

# Don't scan through bb-hosts every time
# This is here for older BB versions without bb-bbexttab
# Uncomment to activate
#CHECK_BB_HOSTS=Y

##################################
# Start of script
##################################

if test ! "$BBHOME"
then
        echo "template: BBHOME is not set"
        exit 1
fi

if test ! -d "$BBHOME"
then
        echo "template: BBHOME is invalid"
        exit 1
fi

# If the first parameter passed is a valid filename, we must want to do testing
if test "$1"
then
  if [ -f $1 ]; then
     DEBUGFILE=$1
     DEBUGMACHINE=$2
     DEBUG="Y"
  fi
fi

if test ! "$BBTMP"                      # GET DEFINITIONS IF NEEDED
then
	if [ -f $BBHOME/etc/bb-def.sh ]; then
       		. $BBHOME/etc/bb-def.sh          # INCLUDE STANDARD BB DEFINITIONS
	fi
	
	if [ -f $BBHOME/etc/hobbitclient.cfg ]; then
       		. $BBHOME/etc/hobbitclient.cfg    # INCLUDE STANDARD HOBBIT DEFINITIONS
	fi
fi

if [ "$DEBUG" = "Y" ]; then
  BB=echo
fi 

#
# Moved these lines down as BBTMP was not defined.
# This caused the script to try to put its files in the root directory
# causing "permission denied" errors since we are not running as root.
#
PRTFILE=$BBTMP/$MACHINE.$TEST.tmp.$$
REDLINE=${BBTMP}/${TEST}-red.$$         
YELLOWLINE=${BBTMP}/${TEST}-yellow.$$   
RED_PIC="&red"          
YELLOW_PIC="&yellow"                      
LEDFILE_FIRSTROW=$BBTMP/$MACHINE.$TEST.led_first.$$
LEDFILE_SECONDROW=$BBTMP/$MACHINE.$TEST.led_second.$$
LEDFILE_THIRDROW=$BBTMP/$MACHINE.$TEST.led_third.$$
LEDFILE_LASTROW=$BBTMP/$MACHINE.$TEST.led_last.$$

#########################
# Start of sub procedures
#########################

#
# Define header
#
get_header()
{
  echo ""
  echo "<FONT SIZE=+2><b>$1</b></FONT> ($2 $3)"
  #If you do not want the header in a bigger font use line below instead
  #  echo "<b>$1</b> ($2 $3)"
}

#
# Define footer
#
get_footer()
{
  echo ""
  #echo "<BR><BR>"
}



get_status () 
{

  #####
  #####  Get Status proc - used to get all responses
  #####

  #####
  #####  Setup some variables for use later
  #####
  COLOR="green"

  check_defaults_set

  #Get machine type
  MACHINETYPE=`echo $PLATFORM_SPEC | $SED 's/.*,//'`

  #check to see if hardware supports temperature checks
  EXCLUDE=`echo $EXCLUDE_SYSTEMS | $EGREP -e "$MACHINETYPE([[:blank:]]+|$)"`

  #####
  #####  Diagnostic Information and more CPU/Memory Info. 
  #####    looking for faults or failures here.
  #####

  # Get prtdiag output
  $PRTDIAG_COMMAND $PRTDIAG_OPT > $PRTFILE

  if [ "$DEBUG" = "Y" ]; then
    MACHINETYPE="$DEBUGMACHINE"  # for testing
    PRTFILE="$DEBUGFILE"    # prtdiag output file you are testing
    EXCLUDE=`echo $EXCLUDE_SYSTEMS | $EGREP -e "$MACHINETYPE([[:blank:]]+|$)"`
    echo ""
    echo "MACHINETYPE pre set: $MACHINETYPE"
    echo "EXCLUDE: $EXCLUDE"
    echo "input file: $PRTFILE"
  fi

  # FSC Primepower Specials Begin
  #
  #
  # Type                                    MACHINETYPE
  # FSC PrimePower 200/400/600 - GP7000F => GPUS
  # FSC PrimePower 250/450/650/850       => GPUSC-M and GPUZC-M
  # FSC PrimePower 900                   => GPUZC-L
  # FSC PrimePower 1000                  => GPUSK

  if [ $ENV_CHECK -eq 1 ] || [ "$CHECK_TEMPERATURE" = "Y" ]; then
     # for all MACHINETYPEs matching "GPU"
     case $MACHINETYPE in
	GPU*)
    		FJPRTDIAG=/opt/FJSVhwr/sbin/fjprtdiag
    		ENV_TEXT=`$GREP "Environmental Status" $PRTFILE`

  		if [ "$DEBUG" = "Y" ]; then
			echo "ENV_TEXT=$ENV_TEXT"
			if [ -x $FJPRTDIAG ]; then
				echo "FJPRTDIAG=$FJPRTDIAG"
			fi
		fi

		# "Environmental Status" is supported by Suns prtdiag under Solaris 5.8, but not under Solaris 5.9
		if [ -z "$ENV_TEXT" ]; then
			if	[ -x $FJPRTDIAG ]; then
  				if [ "$DEBUG" = "Y" ]; then
					echo "No environmental status in standard $PRTDIAG_COMMAND. Would use $FJPRTDIAG"
				else
     		 			$SUDO $FJPRTDIAG $PRTDIAG_OPT > $PRTFILE 
				fi
			else
				echo "No environmental status in standard $PRTDIAG_COMMAND."
			  	echo "No Fujitsu specific $FJPRTDIAG found."
				echo "=> Disabling Environmental and Temperature Checks."
				ENV_CHECK=0
          			CHECK_TEMPERATURE="N"
    			fi
		fi

  	# No Temperature
    	# some PrimePower 200 (such PP200 with 602MHz CPUs) have temperature sensors
    	# and some not (such PP200 with 400MHz CPUs) - Don't know, why ...

        # FSC PrimePower 900                   => GPUZC-L
        #
        # i have only partitioned machines -> these have no temperature
        # but they may have, if unpartitioned
    	#PP_200=`$GREP "PRIMEPOWER 200" $PRTFILE`
    	##TEMPS=`$EGREP '^(Motherboard#[0-9])' $PRTFILE | $AWK '{print $1,$2}'`
        #
        # This is common to all types
    	TEMPS=`$EGREP 'System Temperature' $PRTFILE`
    	if [ "$TEMPS" = "" ]; then
          EXCLUDE="$MACHINETYPE"
    	fi
  		if [ "$DEBUG" = "Y" ]; then
			echo "TEMPS=$TEMPS"
			echo "EXCLUDE=$EXCLUDE"
		fi
        ;;
     esac
  fi
  # FSC Primepower Specials End


  case $MACHINETYPE in
     UltraAX-i2)
          V_CLASS=`$CAT $PRTFILE |
                   $HEAD -1 |
                   $EGREP 'Sun Fire V1|Sun Netra X1' `
          if [ -n "$V_CLASS" ]; then
                EXCLUDE=""
		MACHINETYPE="Sun-Fire-V1xx"
		# Get prtdiag output
		$LOM_COMMAND $LOM_OPT > $PRTFILE
          fi
     ;;

     Sun-Fire-V1xx)
	  get_header "LOM Info" "$LOM_COMMAND" "$LOM_OPT"
     ;;

     *)
	  get_header "Prtdiag Info" "$PRTDIAG_COMMAND" "$PRTDIAG_OPT"
     ;;
  esac

  CATCH_COMMAND=` $CAT $PRTFILE `
  if [ ! "$?" = "0" ]; then
      COLOR="red"
      echo "Problem running $TEST !!!"
  fi
  
  if [ ! "$COLOR" = "red" ]; then
    #####
    #####  Must be good enough to continue.
    #####
      CATCH_COMMAND2=`$CAT $PRTFILE |
                      $GREP Fail |
                      $EGREP -v "$PRTDIAG_IGNORE_ERRORS" `

      if [ ! -z "$CATCH_COMMAND2" ]; then
          COLOR="red"
          echo "${RED_PIC} prtdiag reports some failures !!!" >> $REDLINE
          echo "$CATCH_COMMAND2" >> $REDLINE
      fi
    
      if [ "$MACHINETYPE" = "Netra-T12" ]; then
          CATCH_COMMAND3=`$CAT $PRTFILE |
                          $GREP ault |
                          $GREP ON |
                          $EGREP -v "$PRTDIAG_IGNORE_FAULTS"`
      else
          CATCH_COMMAND3=`$CAT $PRTFILE |
                          $GREP ault |
                          $EGREP -v "$PRTDIAG_IGNORE_FAULTS"`
      fi
      if [ ! -z "$CATCH_COMMAND3" ]; then
          COLOR="red"
          echo "${RED_PIC} prtdiag reports some faults !!!" >> $REDLINE
          echo "$CATCH_COMMAND3" >> $REDLINE
      fi
    
      #####
      #####  Now check for specific components.
      #####    Start with front lights.
      #####

      #####
      #####  E250/E450/280R/480R/V490/V880/V890/PrimePower specific checks
      #####
      if [ "$ENV_CHECK" -eq "1" ]; then
          # Initialise Variables
          # Status are overwritten by prtdiag check
          POWER_ERROR_LIGHT_STATUS=" ON"
          GEN_ERROR_LIGHT_STATUS="OFF"
          DISK_ERROR_LIGHT_STATUS="OFF"
          THERM_ERROR_LIGHT="OFF"
          PS_ERROR_LIGHT_STATUS="OFF"
          ACT_ERROR_LIGHT_STATUS=" ON"
          THERM_ERROR_LIGHT_STATUS="OFF"
          THERML_ERROR_LIGHT_STATUS="OFF"
          THERMR_ERROR_LIGHT_STATUS="OFF"
          DOORL_ERROR_LIGHT_STATUS="OFF"
          DOORR_ERROR_LIGHT_STATUS="OFF"

          PRT_FIRST_LINE=`$CAT $PRTFILE |
                          $HEAD -1 `

          E_CLASS=`echo $PRT_FIRST_LINE |
                   $GREP "Sun Enterprise 450 " `
          if [ -n "$E_CLASS" ]; then
            get_E450_data
          fi

          E_CLASS=`echo $PRT_FIRST_LINE |
                   $GREP "Sun Enterprise 250 " `
          if [ -n "$E_CLASS" ]; then
            get_E250_data
          fi

          E_CLASS=`echo $PRT_FIRST_LINE |
                   $GREP "280R" `
          if [ -n "$E_CLASS" ]; then
            get_280R_data
          fi

          E_CLASS=`echo $PRT_FIRST_LINE |
                   $EGREP "480R|490" `
          if [ -n "$E_CLASS" ]; then
            get_480R_V490_data
          fi

          E_CLASS=`echo $PRT_FIRST_LINE |
                   $EGREP "880|890" `
          if [ -n "$E_CLASS" ]; then
            get_V8x0_data
          fi

          E_CLASS=`echo $PRT_FIRST_LINE |
                   $EGREP "3000|3500|4500" `
          if [ -n "$E_CLASS" ]; then
            get_Exx00_data
          fi

          E_CLASS=`echo $PRT_FIRST_LINE |
                   $EGREP -e "PRIMEPOWER[24]50" `
          if [ -n "$E_CLASS" ]; then
            get_PP250_450_650_850_data "250_450"
          fi

          E_CLASS=`echo $PRT_FIRST_LINE |
                   $EGREP -e "PRIMEPOWER[68]50" `
          if [ -n "$E_CLASS" ]; then
            get_PP250_450_650_850_data "650_850"
          fi

          E_CLASS=`echo $PRT_FIRST_LINE |
                   $EGREP -e "PRIMEPOWER(9|10)00" `
          if [ -n "$E_CLASS" ]; then
            get_PP1000_900_data
          fi

          E_CLASS=`echo $PRT_FIRST_LINE |
                   $EGREP -e "PRIMEPOWER [246]00" `
          if [ -n "$E_CLASS" ]; then
            get_PP200_400_600_data
          fi

          #############################################
          # We now have our data, time to do the checks
          #############################################

          check_general_LEDs
          check_disk_LEDs

      fi

      # do general checks for all systems

      check_disabled_boards
      check_fan_status
      check_power_supplies

      if [ "$MACHINETYPE" = "Sun-Fire-V1xx" ] ||
         [ "$MACHINETYPE" = "Netra-T12" ] ||
         [ "$MACHINETYPE" = "Sun-Fire-V240" ] ||
         [ "$MACHINETYPE" = "Sun-Fire-V440" ] ||
         [ "$MACHINETYPE" = "Sun-Fire-T200" ] ; then
        check_voltage
      fi

      if
         [ "$MACHINETYPE" = "Sun-Fire-T200" ] ; then
        check_current_sensors
        check_current_indicators
      fi

      if [ "$CHECK_TEMPERATURE" = "Y" ]; then
        check_temp_status
      fi

  fi

  # show prtdiag ouput anyway
  echo "${CATCH_COMMAND}"

  get_footer

  #####
  #####  Make sure to export COLOR so that it gets back to "central"
  #####
  export COLOR

#####
#####  End of get_status proc
#####
}



check_defaults_set()
{
  # Check defaults have been set
  if [ "$UNAME" = "" ]; then
    UNAME="/sbin/uname"
    echo ""
    echo "$YELLOW_PIC UNAME command is not defined in etc/bbsys.local - using default: $UNAME"
  fi

  if [ "$PLATFORM_SPEC" = "" ]; then
    PLATFORM_SPEC=`$UNAME -i`
    echo ""
    echo "$YELLOW_PIC PLATFORM_SPEC command is not defined in etc/bbsys.local - using default: $PLATFORM_SPEC"
  fi

  if [ "$PRTDIAG_COMMAND" = "" ]; then
    PRTDIAG_COMMAND="/usr/platform/$PLATFORM_SPEC/sbin/prtdiag"
    echo ""
    echo "$YELLOW_PIC PRTDIAG_COMMAND command is not defined in etc/bbsys.local - using default: $PRTDIAG_COMMAND"
  fi

  if [ "$PRTDIAG_OPT" = "" ]; then
    PRTDIAG_OPT="-v"
    echo ""
    echo "$YELLOW_PIC PRTDIAG_OPT command is not defined in etc/bbsys.local - using default: $PRTDIAG_OPT"
  fi

  if [ "$EXCLUDE_SYSTEMS" = "" ]; then
		EXCLUDE_SYSTEMS="Ultra-1 Ultra-2 Ultra-5_10 Ultra-30 Ultra-60 Ultra-80 UltraAX-i2 UltraSPARC-IIi-cEngine Sun-Fire Netra-T4 UltraAX-e2 Ultra-Enterprise-10000"
    echo ""
    echo "$YELLOW_PIC EXCLUDE_SYSTEMS command is not defined in etc/bbsys.local - using default: $EXCLUDE_SYSTEMS"
  fi

  if [ "$CUT" = "" ]; then
    CUT="/usr/bin/cut"
    echo ""
    echo "$YELLOW_PIC CUT command is not defined in etc/bbsys.local - using default: $CUT"
  fi

  if [ "$PRTDIAG_IGNORE_ERRORS" = "" ]; then
    PRTDIAG_IGNORE_ERRORS="No failures|Most recent AC Power Failure|Minimum Available|CS Fail|No Hardware failures|^===|currently no Boards|Fault     Fan"
    echo ""
    echo "$YELLOW_PIC PRTDIAG_IGNORE_ERRORS variable is not defined in etc/bbsys.local - using default: $PRTDIAG_IGNORE_ERRORS"
  fi

   if [ "$PRTDIAG_IGNORE_FAULTS" = "" ]; then
     PRTDIAG_IGNORE_FAULTS="No Recent System Faults found|No System Faults found|Fault Value|Fault LED|NO_FAULT|Power  Fault|Status        Fault|Fault           off"
     echo ""
     echo "$YELLOW_PIC PRTDIAG_IGNORE_FAULTS variable is not defined in etc/bbsys.local - using default: $PRTDIAG_IGNORE_FAULTS"
   fi

} #end check_defaults_set


get_Exx00_data ()
{

  BAD_LIGHTS=`$AWK '/.Environmental Status./, /^$/ {print $0}' $PRTFILE |
              $GREP -v "^$" |
              $HEAD -5 |
              $TAIL -1 | 
              $GREP -v "Normal" `

  if [ ! -z "$BAD_LIGHTS" ]; then
      COLOR="red"
      echo "${RED_PIC} prtdiag reports front lights are not normal !!!" >> $REDLINE
      echo "$BAD_LIGHTS" >> $REDLINE
  fi

} #end Exx00_checks


get_E450_data ()
{
  #######
  # E450
  #######

  #####
  #####  Individual error LED's on E450
  #####

  # Get first row of led info
  $AWK '/System LED Status./, /^$/ {print $0}' $PRTFILE | \
       $GREP -v "^$" | \
       $HEAD -2 | \
       $TAIL -1 > $LEDFILE_FIRSTROW

  # Get last row of led info
  $AWK '/System LED Status./, /^$/ {print $0}' $PRTFILE | \
       $GREP -v "^$" | \
       $TAIL -1 > $LEDFILE_LASTROW

  POWER_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_FIRSTROW |
                            $CUT -c 24-26 `
  GEN_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_FIRSTROW |
                          $CUT -c 38-40 `

  E_VARIANT=`echo $PRT_FIRST_LINE |
             $GREP " Sun Ultra 450 " `
  if [ -n "$E_VARIANT" ]; then
    # Configured as a workstation: eeprom:mfg-options = 0 or 'workstation'
    ACT_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_FIRSTROW |
                             $CUT -c 54-56 `
  #else
    # Configured as a server: eeprom:mfg-options = 49 or 'server'
    # PRT_FIRST_LINE should contain ' Sun Enterprise 450 '
    # The ACTIVITY led blinks, alternates ON/OFF in prtdiag output,
    # and is useless to us here!!
  fi
 
  DISK_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_LASTROW |
                           $CUT -c 24-26 `
  THERM_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_LASTROW |
                            $CUT -c 38-40 `
  PS_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_LASTROW |
                         $CUT -c 54-56 `

} # end get_E450_data ()

get_PP200_400_600_data ()
{
     ENV_TEXT=`$AWK '/.Environmental Status./, /^$/ {print $0}' $PRTFILE | $EGREP -v "^$|Environmental Status"`

     BAD_LIGHTS=`echo $ENV_TEXT | $EGREP -v -e "MODE switch position|Power Supplies:|Fans:"`
     if [ ! -z "$BAD_LIGHTS" ]; then
         COLOR="red"
         echo "${RED_PIC} prtdiag reports front lights are not normal !!!" >> $REDLINE
         echo "$BAD_LIGHTS" >> $REDLINE
     fi

     MODE_SWITCH=`echo $ENV_TEXT | $GREP "MODE switch position" | $AWK '{print $6}'`
     if [ "$MODE_SWITCH" != "AUTO" ]; then
         COLOR="yellow"
         echo "${YELL_PIC} Mode switch postion = $MODE_SWITCH (recommended AUTO) !!!" >> $YELLOWLINE
     fi
     if [ "$DEBUG" = "Y" ]; then
       echo "ENV_TEXT=$ENV_TEXT"
       echo "BAD_LIGHTS=$BAD_LIGHTS"
       echo "MODE_SWITCH=$MODE_SWITCH"
     fi 
}

get_PP1000_900_data ()
{
     ENV_TEXT=`$AWK '/.Environmental Status./, /^$/ {print $0}' $PRTFILE | $EGREP -v -e "^$|Environmental Status|System PROM revisions|^-*$|RST .* POST"`

     BAD_LIGHTS=`echo $ENV_TEXT | $GREP -v "MODE switch position"`
     MODE_SWITCH=`echo $ENV_TEXT | $GREP "MODE switch position" | $AWK '{print $6}'`

     if [ ! -z "$BAD_LIGHTS" ]; then
         COLOR="red"
         echo "${RED_PIC} prtdiag reports front lights are not normal !!!" >> $REDLINE
         echo "$BAD_LIGHTS" >> $REDLINE
     fi
     if [ "$MODE_SWITCH" != "UNLOCK" ]; then
         COLOR="yellow"
         echo "${YELL_PIC} Mode switch postion = $MODE_SWITCH (recommended UNLOCK) !!!" >> $YELLOWLINE
     fi
     if [ "$DEBUG" = "Y" ]; then
       echo "ENV_TEXT=$ENV_TEXT"
       echo "BAD_LIGHTS=$BAD_LIGHTS"
       echo "MODE_SWITCH=$MODE_SWITCH"
     fi 
}

get_PP250_450_650_850_data ()
{
	PP_TYPE=$1
	 ENV_TEXT=`$AWK '/.Environmental Status./, /^$/ {print $0}' $PRTFILE | $EGREP -v "^$|Environmental Status"`

     BAD_LIGHTS=`echo $ENV_TEXT | $GREP -v "MODE switch position"`
     MODE_SWITCH=`echo $ENV_TEXT | $GREP "MODE switch position" | $AWK '{print $6}'`

     if [ ! -z "$BAD_LIGHTS" ]; then
         COLOR="red"
         echo "${RED_PIC} prtdiag reports front lights are not normal !!!" >> $REDLINE
         echo "$BAD_LIGHTS" >> $REDLINE
     fi
     ### u. kirbach ###
		 # PP_TYPE == 650_850
     #   if MODE_SWITCH == UNLOCK, then machine does not reboot after a crash 
     #   (auto-boot?=true is then useless at PP650 and PP850)
		 #   but with MODE_SWITCH = LOCK you can not bring this machine into OBP with <Stop-A>
     if [ "$PP_TYPE" = "250_450" -a "$MODE_SWITCH" != "UNLOCK" ]; then
       COLOR="yellow"
       echo "${YELL_PIC} Mode switch postion = $MODE_SWITCH (recommended UNLOCK) !!!" >> $YELLOWLINE
     fi
     if [ "$PP_TYPE" = "650_850" -a "$MODE_SWITCH" != "LOCK" ]; then
       COLOR="yellow"
       echo "${YELL_PIC} Mode switch postion = $MODE_SWITCH (recommended LOCK) !!!" >> $YELLOWLINE
     fi
     if [ "$DEBUG" = "Y" ]; then
       echo "ENV_TEXT=$ENV_TEXT"
       echo "BAD_LIGHTS=$BAD_LIGHTS"
       echo "MODE_SWITCH=$MODE_SWITCH"
     fi 
}

get_E250_data ()
{
  #####
  #####  Individual error LED's on E250
  #####

  # Get first row of led info
  $AWK '/System LED Status./, /^$/ {print $0}' $PRTFILE | \
       $GREP -v "^$" | \
       $HEAD -2 | \
       $TAIL -1 > $LEDFILE_FIRSTROW

  # Get middle row of led info
  $AWK '/System LED Status./, /^$/ {print $0}' $PRTFILE | \
       $GREP -v "^$" | \
       $TAIL -4 | \
       $HEAD -2 | \
       $TAIL -1 > $LEDFILE_SECONDROW

  # Get last row of led info
  $AWK '/System LED Status./, /^$/ {print $0}' $PRTFILE | \
       $GREP -v "^$" | \
       $TAIL -2 | \
       $TAIL -1 > $LEDFILE_LASTROW

  # First Row
  DISK_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_FIRSTROW |
                           $CUT -c 24-26 `
  POWER_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_FIRSTROW |
                            $CUT -c 38-40 `

  # Second Row
  PS_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_SECONDROW |
                         $CUT -c 24-26 `

  # Unlike the E450, it doesn't seem to matter whether we are configured as a
  #    server:      eeprom:mfg-options = server
  # or workstation: eeprom:mfg-options = workstation,
  # (not that I can find those options documented for the E250),
  # PRT_FIRST_LINE always contains ' Sun (TM) Enterprise 250 ',
  # the ACTIVITY led blinks, and alternates ON/OFF in prtdiag output,
  # and is useless to us here!!
  ##ACT_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_SECONDROW |
  ##                        $CUT -c 38-40 `

  # Last Row
  GEN_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_LASTROW |
                          $CUT -c 24-26 `
  THERM_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_LASTROW |
                            $CUT -c 38-40 `

} # end get_E250_data ()


get_280R_data ()
{
  #######
  # 280R
  #######

  #####
  #####  Individual error LED's on V280R
  #####

  # Get first row of led info
  $AWK '/System LED Status./, /^$/ {print $0}' $PRTFILE | \
    $GREP -v "^$" | \
    $HEAD -3 | \
    $TAIL -1 > $LEDFILE_FIRSTROW

    # First Row
    POWER_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_FIRSTROW |
                              $CUT -c 21-23 `
    GEN_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_FIRSTROW |
                              $CUT -c 46-48 `

} # end get_E280_data ()


get_480R_V490_data ()
{
  #######
  # 480R V490
  #######

  #####
  #####  Individual error LED's on 480R and V490
  #####

  # Get first row of led info
  $AWK '/System LED Status./, /\=/ {print $0}' $PRTFILE | \
    $GREP -v "^$" | \
    $HEAD -4 | \
    $TAIL -1 > $LEDFILE_FIRSTROW

    # First Row
    POWER_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_FIRSTROW |
                              $CUT -c23-25 `
    GEN_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_FIRSTROW |
                              $CUT -c14-16 `

} # end get_480R_V490_data ()


get_V8x0_data ()
{

  ############
  # V880/V890
  ############

  #####
  #####  Individual error LED's on V880/V890
  #####

  # Get first row of led info
  $AWK '/System LED Status./, /^===/ {print $0}' $PRTFILE | \
       $GREP -v "^$" | \
       $HEAD -3 | \
       $TAIL -1 > $LEDFILE_FIRSTROW

  # Get second row of led info
  $AWK '/System LED Status./, /^===/ {print $0}' $PRTFILE | \
       $GREP -v "^$" | \
       $HEAD -5 | \
       $TAIL -1 > $LEDFILE_SECONDROW

  # Get third row of led info
  $AWK '/System LED Status./, /^===/ {print $0}' $PRTFILE | \
       $GREP -v "^$" | \
       $HEAD -7 | \
       $TAIL -1 > $LEDFILE_THIRDROW

  # Get last row of led info
  $AWK '/System LED Status./, /^===/ {print $0}' $PRTFILE | \
       $GREP -v "^$" | \
       $HEAD -9 | \
       $TAIL -1 > $LEDFILE_LASTROW

  # First Row
  GEN_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_FIRSTROW |
                          $CUT -c 22-24 `
  REMOVE_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_FIRSTROW |
                             $CUT -c 47-49 `

  # Second Row
  DISK_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_FIRSTROW |
                           $CUT -c 22-24 `
  POWER_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_FIRSTROW |
                            $CUT -c 47-49 `

  # Third Row
  LEFT_THERMAL_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_THIRDROW |
                                   $CUT -c 22-24 `
  RIGHT_THERMAL_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_THIRDROW |
                                    $CUT -c 47-49 `

  # Last Row
  LEFT_DOOR_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_LASTROW |
                                $CUT -c 22-24 `
  RIGHT_DOOR_ERROR_LIGHT_STATUS=`$CAT $LEDFILE_LASTROW |
                                 $CUT -c 47-49 `

} # end get_V8x0_data ()



check_general_LEDs ()
{
      #####
      #####  Individual error LED's checks
      #####

      if [ ! "$GEN_ERROR_LIGHT_STATUS" = "OFF" ]; then
              COLOR="red"
              echo "${RED_PIC} prtdiag reports general error light is on !!!" >> $REDLINE
              echo "$GEN_ERROR_LIGHT" >> $REDLINE
      fi

      case $MACHINETYPE in
      Sun-Fire-*8[89]0)
              if [ ! "$POWER_ERROR_LIGHT_STATUS" = "OFF" ]; then
                      COLOR="red"
                      echo "${RED_PIC} prtdiag reports power error light is on !?!" >> $REDLINE
                      echo "$POWER_LIGHT_STATUS" >> $REDLINE
              fi

              if [ ! "$REMOVE_ERROR_LIGHT_STATUS" = "OFF" ]; then
                      COLOR="red"
                      echo "${RED_PIC} prtdiag reports remove error light is on !!!" >> $REDLINE
                      echo "$REMOVE_ERROR_LIGHT" >> $REDLINE
              fi

              if [ ! "$LEFT_THERMAL_ERROR_LIGHT_STATUS" = "OFF" ]; then
                      COLOR="red"
                      echo "${RED_PIC} prtdiag reports left thermal error light is on !!!" >> $REDLINE
                      echo "$LEFT_THERM_ERROR_LIGHT" >> $REDLINE
              fi

              if [ ! "$RIGHT_THERMAL_ERROR_LIGHT_STATUS" = "OFF" ]; then
                      COLOR="red"
                      echo "${RED_PIC} prtdiag reports right thermal error light is on !!!" >> $REDLINE
                      echo "$RIGHT_THERM_ERROR_LIGHT" >> $REDLINE
              fi

              if [ ! "$LEFT_DOOR_ERROR_LIGHT_STATUS" = "OFF" ]; then
                      COLOR="red"
                      echo "${RED_PIC} prtdiag reports left door error light is on !!!" >> $REDLINE
                      echo "$LEFT_DOOR_ERROR_LIGHT" >> $REDLINE
              fi

              if [ ! "$RIGHT_DOOR_ERROR_LIGHT_STATUS" = "OFF" ]; then
                      COLOR="red"
                      echo "${RED_PIC} prtdiag reports right door error light is on !!!" >> $REDLINE
                      echo "$RIGHT_DOOR_ERROR_LIGHT" >> $REDLINE
              fi

              ;;

      * )
              if [ ! "$POWER_ERROR_LIGHT_STATUS" = " ON" ]; then
                      COLOR="red"
                      echo "${RED_PIC} prtdiag reports power error light is off !?!" >> $REDLINE
                      echo "$POWER_LIGHT_STATUS" >> $REDLINE
              fi

              if [ ! "$DISK_ERROR_LIGHT_STATUS" = "OFF" ]; then
                      COLOR="red"
                      echo "${RED_PIC} prtdiag reports disk error light is on !!!" >> $REDLINE
                      echo "$DISK_LIGHT_STATUS" >> $REDLINE
              fi

              if [ ! "$THERM_ERROR_LIGHT_STATUS" = "OFF" ]; then
                      COLOR="red"
                      echo "${RED_PIC} prtdiag reports thermal error light is on !!!" >> $REDLINE
                      echo "$THERM_ERROR_LIGHT" >> $REDLINE
              fi

              if [ ! "$PS_ERROR_LIGHT_STATUS" = "OFF" ]; then
                      COLOR="red"
                      echo "${RED_PIC} prtdiag reports power supply error light is on !!!" >> $REDLINE
                      echo "$PS_ERROR_LIGHT" >> $REDLINE
              fi

              if [ ! "$ACT_ERROR_LIGHT_STATUS" = " ON" ]; then
                      COLOR="red"
                      echo "${RED_PIC} prtdiag reports activity error light is off !!!" >> $REDLINE
                      echo "$ACT_ERROR_LIGHT_STATUS" >> $REDLINE
              fi

              ;;
      esac

      if [ "$DEBUG" = "Y" ]; then
            echo "GEN_ERROR_LIGHT_STATUS: $GEN_ERROR_LIGHT_STATUS"
      fi 

} # end check_general_LEDs ()


check_disk_LEDs ()
{

  #####
  #####  Individual disk LED's
  #####

  case $MACHINETYPE in
        Sun-Fire-280R)
          DISK_LIGHTS=`$AWK '/Disk Status./, /^$/ {print $0}' $PRTFILE |
                       $GREP -v "^$" |
                       $TAIL +4 |
                       $EGREP -v "(NO_FAULT|EMPTY)" `
              ;;

        Sun-Fire-480R)
          DISK_LIGHTS=`$AWK '/Disk Status./, /^$/ {print $0}' $PRTFILE |
                       $GREP -v "^$" |
                       $TAIL +3 |
                       $EGREP -v "(NO_FAULT|EMPTY)" `
              ;;
        Sun-Fire-V490)
          DISK_LIGHTS=`$AWK '/Disk Status./, /^$/ {print $0}' $PRTFILE |
                       $GREP -v "^$" |
                       $TAIL +3 |
                       $EGREP -v "(NO_FAULT|EMPTY)" `
              ;;

        Sun-Fire-*8[89]0)
          DISK_LIGHTS=`$AWK '/Disk Status./, /^$/ {print $0}' $PRTFILE |
                       $GREP -v "^$" |
                       $TAIL +3 |
                       $GREP "ON" `
              ;;

        Sun-Fire-V[24]40)

          # Expected result
          #HDD0       SERVICE               off         amber
          #HDD0       OK2RM                 off         blue
          #HDD1       SERVICE               off         amber
          #HDD1       OK2RM                 off         blue
          #HDD2       SERVICE               off         amber
          #HDD2       OK2RM                 off         blue
          #HDD3       SERVICE               off         amber
          #HDD3       OK2RM                 off         blue

          DISK_LIGHTS=`$AWK '/^HDD/ {
                         if ($3 == "on" && $4 != "green")
                         {print $0} }' $PRTFILE`

              ;;

        Netra-T4)

          # Expected result
          #HDD 0      HDD 0 OK to remove    off         blue
          #HDD 0      HDD 0 Fault           off         amber
          #HDD 0      HDD 0 Power           on          green
          #HDD 1      HDD 1 OK to remove    off         blue
          #HDD 1      HDD 1 Fault           off         amber
          #HDD 1      HDD 1 Power           on          green

          DISK_LIGHTS=`$AWK '/^HDD/ { 
                         if ($6 == "on" && $7 != "green")
                         {print $0} }' $PRTFILE`

              ;;

        Sun-Fire-T200)

          # Expected result
          #HDD0        SERVICE        off     
          #HDD0        OK2RM          off     
          #HDD1        SERVICE        off     
          #HDD1        OK2RM          off     
          #HDD2        SERVICE        off     
          #HDD2        OK2RM          off     
          #HDD3        SERVICE        off     
          #HDD3        OK2RM          off 

	  DISK_LIGHTS=`$AWK '/^HDD/ {
                         if ($3 != "off")
                         {print $0} }' $PRTFILE`

              ;;

        *)
          DISK_LIGHTS=`$AWK '/Disk LED Status./, /^$/ {print $0}' $PRTFILE |
                       $EGREP -v "^$|===" |
                       $TAIL +2 |
                       $GREP "ERROR" `
              ;;
  esac

  #####
  #####  Individual disk LED's checks
  #####

  if [ ! -z "$DISK_LIGHTS" ]; then
       COLOR="red"
       echo "${RED_PIC} prtdiag reports some of the disks have problems !!!" >> $REDLINE
       echo "$DISK_LIGHTS" >> $REDLINE
  fi
    
  if [ "$DEBUG" = "Y" ]; then
       echo "DISK_LIGHTS: $DISK_LIGHTS"
  fi 

} # end check_disk_LEDs ()


check_disabled_boards()
{
  #####
  #####  Now check for disabled boards.
  #####

  case $MACHINETYPE in
      Sun-Fire)

        BAD_BOARDS=`$AWK '/^==+ Active Boards/, /^==+ Available/ {
                  if ( ($2 != "on" || $3 != "off" || $4 != "off" || $5 != "ok") |
                      ( $3 != "connect" || $4 != "configured" || $5 != "ok") 
                     )
                 {print $0}}' $PRTFILE |
                    $EGREP -v '^$|==|--|FRU Name|HotPlug'`
        ;;
#        BAD_BOARDS=`$AWK '/^==/{x=0}/Active Boards/{x=1}{
#                            if (x==1)
#                            {if ($14 != "Green" && $14 != "12.0V" && $14 != "------" && $14 != "")
#                             print $0}
#                          }' $PRTFILE`

      Sun-Fire-T200)
            BAD_BOARDS=`$GREP "SYS " $PRTFILE |
                        $EGREP -v "off|steady"`

        ;;

      *)

         BOARD_CHECK=`$CAT $PRTFILE | $GREP "Detached Boards" `

         if [ ! -z "$BOARD_CHECK" ]; then
           BAD_BOARDS=`$AWK '/Detached Boards/,/^$/ { 
                            if ($2 == "disabled" && $3 != "disk")
                            {print $0} }' $PRTFILE`
         fi

       ;;
   esac

   if [ ! -z "$BAD_BOARDS" ]; then
       COLOR="red"
       echo "${RED_PIC} prtdiag reports some boards are disabled !!!" >> $REDLINE
       echo "\"$BAD_BOARDS\"" >> $REDLINE
   fi
}
    

check_fan_status()
{
  #####
  #####  Now check for fans.
  #####

  FAN_CHECK=`$CAT $PRTFILE | $EGREP '(ft_f|Fans:|Fan Status:|Fan Bank :|Fan Speeds:|Fan sensors:)' `

  if [ ! -z "$FAN_CHECK" ]; then
      case $MACHINETYPE in

          Sun-Fire-280R)
            BAD_FANS=`$AWK '/Fan Bank/, /^====/ {print $0}' $PRTFILE |
                      $GREP -v "^$" |
                      $GREP -v "^==" |
                      $TAIL +5 |
                      $GREP -v "NO_FAULT" `
              ;;
          Sun-Fire-480R)
            BAD_FANS=`$AWK '/Fan Tray/, /^$/ {print $0}' $PRTFILE |
                      $GREP -v "^$" |
                      $TAIL +5 |
                      $GREP -v "NO_FAULT" `
              ;;

          Sun-Fire-V490)
            BAD_FANS=`$AWK '/Fan Tray/, /^$/ {print $0}' $PRTFILE |
                      $GREP -v "^$" |
                      $TAIL +5 |
                      $GREP -v "NO_FAULT" `
              ;;

          Sun-Fire-*8[89]0)
            BAD_FANS=`$AWK '/Fan Bank/, /^====/ {print $0}' $PRTFILE |
                      $GREP -v "^$" |
                      $GREP -v "^==" |
                      $TAIL +6 |
                      $GREP -v "OK" `
              ;;
	  Sun-Fire-V1xx)
            BAD_FANS=`$AWK '/^Fans:/, /speed/ {print $0}' $PRTFILE |
	              $TAIL +2 |
                      $GREP -v "OK"` 
	      ;;
          Ultra-Enterprise)
            BAD_FANS=`$AWK '/^Fans:/, /^$/ {print $0}' $PRTFILE |
                      $GREP -v "^$" |
                      $TAIL -1 |
                      $GREP -v "OK" `
	      ;;
          Netra-T12)
            BAD_FANS=`$GREP "ft_f" $PRTFILE |
                      $EGREP -v "okay|self"`
              ;;
          Sun-Fire-V240)
            BAD_FANS=`$GREP "FF_FAN" $PRTFILE |
                      $GREP -v "okay"`
              ;;
          Sun-Fire-V440)
            BAD_FANS=`$EGREP "TACH|FAN" $PRTFILE |
                      $EGREP -v "okay|self"`
              ;;
          # FSC PrimePower 200, 400 and 600
          GPUS)
            BAD_FANS=`$AWK '/^Fans:/, /^$/ {print $0}' $PRTFILE |
                      $GREP -v "^$" |
                      $TAIL -1 |
                      $GREP -v "OK" `
	      ;;
          A70)
            BAD_FANS=`$AWK '/^Fan Status:/, /^$/ {print $0}' $PRTFILE |
                      $EGREP -v "Fan Status|okay|Location|---"`
	      ;;
          Sun-Fire-T200)
            BAD_FANS=`$AWK '/^Fan sensors:/, /^$/ {print $0}' $PRTFILE |
                      $EGREP -v "Fan sensors|ok|Location|---"`
              ;;
          *)
            BAD_FANS=`$AWK '/Fans:/, /^$/ {print $0}' $PRTFILE |
                      $GREP -v "^$" |
                      $TAIL +5 |
                      $GREP -v "OK" `
              ;;
      esac

      if [ ! -z "$BAD_FANS" ]; then
          COLOR="red"
          echo "${RED_PIC} prtdiag reports cooling fans are not ok !!!" >> $REDLINE
          echo "$BAD_FANS" >> $REDLINE
      fi
  fi

  if [ "$DEBUG" = "Y" ]; then
    echo "FAN_CHECK: $FAN_CHECK"
    echo "BAD_FANS: $BAD_FANS"
  fi

} # end check_fan_staus


check_temp_status() 
{

  if [ -n "$EXCLUDE" ]; then
      echo "No Temperature Report"
      echo "  This type of computer ($MACHINETYPE) does "
      echo "  not report system temperature."
      echo
  else
    get_temp_data
    if [ "$NO_REPORT" !=  "3" ]; then
      process_temp_data
    else
                echo "No Temperature Report"
                echo "  This program does not know where to get the temperature"
                echo "  readings for your computer ($MACHINETYPE), as they were"
                echo "  not in the output of \"$PRTFILE\""
                echo "  This is known to happen on systems with domains."
    fi
  fi
} # end check_temp_status

get_temp_data()
{

  #####
  #####  Now check for Board Temps.
  #####

      #Get the diagnostics data, parse out the temperatures, 
      #make them comma delimited, and remove the trailing comma

      case $MACHINETYPE in

          Ultra-Enterprise)
            # Enterprise 3x00, 4x00, 5x00 & 6x00
            # prtdiag output is different on Solaris 2.5.1 than on 2.6 and later
            if [ "$OSREL" = "5.5.1" ]; then
              TEMPS=`$CAT $PRTFILE |
                $EGREP '^(Board [0-9]+|Control Board): +[0-9]+ +[A-Za-z]+$'|
                $SED -e 's/Board /Board_/g' -e 's/Control /Control_/g' -e 's/://' |
                $AWK '{print $1,$2,","}'`
            else
              TEMPS=`$CAT $PRTFILE |
                       $EGREP '^( +[0-9A-Z]+|CLK) +[A-Z]+ +[0-9]+' |
                       $EGREP -vi '(PCI|UPA|SBus|Unknown|MHz)' |
                       $SED -e 's/^*/Board_/g' -e 's/^CLK/Clock_Board/g' |
                       $AWK '{print $1,$3,","}'`
            fi
            ;;

          Ultra-4) 
            TEMPS=`$CAT $PRTFILE |
                   $SED -n '/^System Temp/,/^======/p' |
                   $SED 's/CPU /CPU/g' |
                   $EGREP '^[A-Z0-9]+ +[0-9]+$'|
                   $SED 's/ *\([0-9A-Z]*\) *\([0-9]*\)/\1 \2,/g'`;
              ;;

          Sun-Blade-1000|Sun-Blade-100)
            TEMPS=`$CAT $PRTFILE |
                   $EGREP '^ +[0-9] .+[0-9]+ C +[0-9]+ C' |
                   $AWK '{print "CPU_" $1 "_Die",$7,", CPU_" $1 "_Ambient",$9,","}'`
              ;;

          Sun-Blade-1000|Sun-Blade-100|Sun-Blade-150|Sun-Blade-1500|Sun-Blade-2500)
            TEMPS=`$EGREP '^ +[0-9] .+[0-9] C .+[0-9] C' $PRTFILE |
                   $AWK '{print "CPU_" $1 "_Die",$7,", CPU_" $1 "_Ambient",$9,","}'`
                   if [ "$TEMPS" = "" ]; then
                           # prtdiag output is different on Solaris 9
                           TEMPS=`$EGREP 'SUNW.+[0-9]C .+[0-9]C' $PRTFILE |
                                  $AWK '{gsub("C","");print "CPU_" $1 "_Die",$7,", CPU_" $1 "_Ambient",$8,","}'`
                   fi
              ;;

          Sun-Fire)
            # Sun Fire 3800, 4800, 4810 & 6800 servers
						### u. kirbach ###
						### u. kirbach ### i have also seen machines not only with CPUs US-III but also with US-III+
						### u. kirbach ###
            ### u. kirbach ###TEMPSCPU=`$CAT $PRTFILE |
            ### u. kirbach ###          $EGREP '^/N[0-9]+/.+ US-III .+[0-9]+ ' |
            ### u. kirbach ###          $AWK ' {print "CPU_" $1,$7,","}'`
            TEMPSCPU=`$CAT $PRTFILE |
            			$EGREP '^/N[0-9]+/.+ US-III? .+[0-9]+ ' |
							$AWK '{if ($7 > 0) {print "CPU_" $1,$7,","}}'`
            TEMPSBRDS=`$CAT $PRTFILE |
                       $EGREP '^/N[0-9]+/.+ ( on | off ) .+[0-9]+ ' |
                       $AWK '{if ($6 > 0) {print "Board_" $1 "_0",$6,","};  \
                              if ($7 > 0) {print " Board_" $1 "_1",$7,","}; \
                              if ($8 > 0) {print " Board_" $1 "_2",$8,","}; \
                              if ($9 > 0) {print " Board_" $1 "_3",$9,","}}'`

                        if [ "$TEMPSCPU$TEMPSBRDS" = "" ]; then
                                # May not have temps on systems with domains
                                NO_REPORT=3
                        else
                                TEMPS="$TEMPSCPU $TEMPSBRDS"
                        fi

            ;;

          Sun-Fire-*8[89]0)
            TEMPS=`$CAT $PRTFILE |
                   $EGREP '^(MB|IO|IOB|BP[0-9]|CPU[0-9]+|DBP0)[^a-zA-Z]+[0-9]+'|
                   $AWK '{print $1,$2,","}'`
            ;;

          Sun-Fire-280R)
            CPUS=` $CAT $PRTFILE |
                   $EGREP '^cpu(0|1)'`
            CPUS=`echo $CPUS`
            CPULINE=`$CAT $PRTFILE | 
                     $EGREP -n '^cpu(0|1)' |
                     $AWK -F: '{print $1}'`
            TEMPLINE=`$EXPR 0$CPULINE + 2`
            TEMPS=`$CAT $PRTFILE | $SED -n ${TEMPLINE}p | $AWK '{
                   if ( $1 =="xx" ) {print "cpu1",$2 }
                   else if ( $2 =="xx" ) {print "cpu0",$1 }
                     else { print "cpu0",$1,",cpu1",$2} }'`
            ;;

          Sun-Fire-480R)
            TEMPS=`$CAT $PRTFILE |
                   $EGREP '^(CPU[0-9]+|DBP0)[^a-zA-Z]+[0-9]+'|
                   $EGREP -v 'NO_FAULT' |
                   $AWK '{print $1,$2,","}'`
             ;;

          Sun-Fire-V490)
            TEMPS=`$CAT $PRTFILE |
                   $EGREP '^(CPU[0-9]+|DBP0)[^a-zA-Z]+[0-9]+'|
                   $EGREP -v 'NO_FAULT' |
                   $AWK '{print $1,$2,","}'`
             ;;

          #Sun-Fire-V2[14]0)
            #TEMPS=`$CAT $PRTFILE |
                   #$EGREP 'T_CORE|T_ENC' |
                   #$AWK '{print $1,$3,$6,$7,","}' |
                   #$SED 's/C//g'`
             #;;

          Sun-Fire-V1xx)
            TEMPS=`$CAT $PRTFILE |
                   $GREP "Enclosure"|
                   $AWK '{print $2,$3,","}'`
             ;;

          Netra-T12)
            TEMPSCPU=`$CAT $PRTFILE |
                      $GREP "SPARC"|
                      $SED 's/,[0-9][0-9][0-9]//g' |
                      $SED 's/C//g' |
                      $AWK '{print "CPU_" $1 "_Die",$7,", CPU_" $1 "_Ambient",$8,","}'`

            TEMPSBRDS=`$CAT $PRTFILE |
                       $GREP -v "SPARC"|
                       $GREP "[0-9]C"|
                       $SED 's/C / /g' |
                       $AWK '{print $1,$3,$6,$7,","}'`
            TEMPS="$TEMPSCPU $TEMPSBRDS"

             ;;

          Sun-Fire-V440)
            TEMPS=`$CAT $PRTFILE |
                   $EGREP "T_AMB|T_CORE" |
                   $SED 's/C / /g' |
                   $AWK '{print $1,$3,$6,$7,","}'`
             ;;

           # FSC PrimePower 250/450/650/850       => GPUSC-M and GPUZC-M
           # FSC PrimePower 200/400/600 - GP7000F => GPUS
           GPUSC-M|GPUZC-M|GPUS)
             TEMPS=`$AWK '/^(AMBIENT|Motherboard#[0-9])/ {print $1,$2,","}
					 							  /^FEP#[0-9]/ {print $1,$4,","}'	$PRTFILE `
             ;;

          * ) 
            TEMPS=`$CAT $PRTFILE | 
                   $EGREP '^ +[0-9A-Z]+ +[0-9]+$'|
                   $SED 's/ *\([0-9A-Z]*\) *\([0-9]*\)/\1 \2,/g'`;
             ;;
        
      esac

      TEMPS=`echo $TEMPS | $SED 's/,$//'`

      if [ "$DEBUG" = "Y" ]; then
        echo "TEMPS: $TEMPS"
      fi

} # get_temp_data()

process_temp_data()
{

      #Do the output conversions
      echo $TEMPS | $AWK -v SYSTEM=$MACHINETYPE \
                         -v YELL=$YELLOWLINE \
                         -v REDL=$REDLINE \
                         -v THISH=$MACHINE \
                         -v PROG=$TEST \
                         -v GRED=$RED_PIC \
                         -v GYEL=$YELLOW_PIC \
                         -v DEBUG=$DEBUG \
        'BEGIN { RS = "," } { 

              #This checks the system type and set the temperate ranges
              #for different systems.  Be conservative if unknown system
              if (SYSTEM == "Ultra-4" || SYSTEM == "Ultra-Enterprise") {
                      CPUHIGHPANIC=85;
                      CPUHIGHWARN=75;

                  } else if (SYSTEM == "Ultra-250") {
                        if ($1 ~ /Die/) {
                                # System Warning & LED at 60
                                # System Shutdown at 65
                                CPUHIGHPANIC=60;
                                CPUHIGHWARN=55;
                        }
                        if ($1 ~ /Ambient/) {
                                # System Warning & LED at 53
                                # System Shutdown at 58
                                CPUHIGHPANIC=53;
                                CPUHIGHWARN=48;
                        }

                  } else if (SYSTEM == "Sun-Blade-1000" || SYSTEM == "Sun-Blade-1500") {
                        if ($1 ~ /Die/) {
                                CPUHIGHPANIC=90;
                                CPUHIGHWARN=85;
                        }
                        if ($1 ~ /Ambient/) {
                                # Guess here - typical is 25 (room temp)
                                CPUHIGHPANIC=40;
                                CPUHIGHWARN=30;
                        }

                  } else if (SYSTEM == "Sun-Blade-100") {
                        if ($1 ~ /Die/) {
                                # Guesses here - typical is 55
                                CPUHIGHPANIC=70;
                                CPUHIGHWARN=65;
                        }
                        if ($1 ~ /Ambient/) {
                                # Guess here - typical is 25 (room temp)
                                CPUHIGHPANIC=40;
                                CPUHIGHWARN=30;
                        }

                  } else if (SYSTEM == "Sun-Fire") {
                        if ($1 ~ /CPU/) {
                                # Guesses here - typical is 65
                                CPUHIGHPANIC=80;
                                CPUHIGHWARN=75;
                        }
                        if ($1 ~ /Board/) {
                                # Guess here - typical is 20-30
                                CPUHIGHPANIC=60;
                                CPUHIGHWARN=50;
                        }

                  } else if (SYSTEM == "Sun-Fire-480R" || SYSTEM == "Sun-Fire-V490") {
                      # Guesses here - typical is 65
                      CPUHIGHPANIC=70;
                      CPUHIGHWARN=65;
                      if ($1 ~ /BP[01]/) {
                         # Guess here - typical is 20-30
                         CPUHIGHPANIC=60;
                         CPUHIGHWARN=50;
                      }

                  } else if (SYSTEM == "Sun-Fire-880" || SYSTEM=="Sun-Fire-V890") {
                      # typical is 65
                      # limits from "prtpicl -v -c temperature-sensor"
                      # CPU will shutdown at 100
                      CPUHIGHPANIC=85;
                      CPUHIGHWARN=80;
                      if ($1 ~ /BP[01]/) {
                         # typical is 20-30
                         # DBP will shutdown at 55
                         CPUHIGHPANIC=52;
                         CPUHIGHWARN=47;
                      } else if ($1 ~ /IOB/) {
                         # typical is 20-30
                         # IOB will shutdown at 53
                         CPUHIGHPANIC=49;
                         CPUHIGHWARN=44;
                      } else if ($1 ~ /MB/) {
                         # typical is 30-40
                         # MB will shutdown at 75
                         CPUHIGHPANIC=70;
                         CPUHIGHWARN=65;
                      }

                  } else if (SYSTEM == "Sun-Fire-280R") {
                      # typical is 60
                      # limits from "prtpicl -v -c temperature-sensor"
                      # system will shutdown at 95
                      CPUHIGHPANIC=80;
                      CPUHIGHWARN=75;

                  } else if (SYSTEM == "Sun-Fire-V210") {
                      # Guesses here taken from prtdiag output
                      CPUHIGHPANIC=115;
                      CPUHIGHWARN=110;

                #  } else if (SYSTEM == "Sun-Fire-V240") {
                #      # Use values from prtdiag report
                #      # Less 10, we want to know about issues before
                #      # the system starts to complain
                #      CPUHIGHPANIC=$4-10;
                #      CPUHIGHWARN=$3-10;

                  } else if (SYSTEM == "Sun-Fire-V440") {
                        # Use values from prtdiag report
                        # Less 10, we want to know about issues before
                        # the system starts to complain
                        CPUHIGHPANIC=$4-10;
                        CPUHIGHWARN=$3-10;

                  } else if (SYSTEM == "Sun-Fire-V1xx") {
                      # Taken from LOM output 
                      CPUHIGHPANIC=72;
                      CPUHIGHWARN=67;

                  } else if (SYSTEM == "Netra-T12") {
                        if ($1 ~ /Die/) {
                                # Guesses here - typical is 55
                                CPUHIGHPANIC=90;
                                CPUHIGHWARN=80;
                        } else if ($1 ~ /Ambient/) {
                                # Guess here - typical is 30
                                CPUHIGHPANIC=55;
                                CPUHIGHWARN=45;
                        } else {
                                # Use values from prtdiag report
                                CPUHIGHPANIC=$4;
                                CPUHIGHWARN=$3;
                        }

                  } else if (SYSTEM == "GPUSC-M" || SYSTEM == "GPUZC-M") {
                     # FSC PrimePower 850 & 650 & 450 & 250
                     if ($1 ~ /AMBIENT/) {
                        # Guess here - typical is 25 (room temp)
                        CPUHIGHPANIC=40;
                        CPUHIGHWARN=35;
                        }

                  } else if (SYSTEM == "GPUS") {
                     # FSC GP7000 or PrimePower 600 or 400 or 200 (with Temperature)
                     if ($1 ~ /Motherboard#/) {
                        # Guess here - typical is 30
                        CPUHIGHPANIC=50;
                        CPUHIGHWARN=42;
                     } else if ($1 ~ /AMBIENT/) {
                        # Guess here - typical is 30
                        CPUHIGHPANIC=50;
                        CPUHIGHWARN=40;
                      } else if ($1 ~ /FEP#/) {
                        # Guess here - typical is 32
                        CPUHIGHPANIC=50;
                        CPUHIGHWARN=42;
											}
                  } else {
                       CPUHIGHWARN=70;
                       CPUHIGHPANIC=75;
                       print "--------------------------------------";
                       print "Program does not have operating range";
                       print "    for ",SYSTEM," type computers.";
                       print "     Using sane values as defaults";
                       print "--------------------------------------"
              } 
        if ( DEBUG == "Y" ) {
	  print "SYSTEM ",SYSTEM;
          print "CPUHIGHWARN ",CPUHIGHWARN;
          print "CPUHIGHPANIC ",CPUHIGHPANIC;
          print "dollar 0 ",$0;
          print "dollar 1 ",$1;
          print "dollar 2 ",$2;
          print "dollar 3 ",$3;
          print "dollar 4 ",$4;
	  #print "Device             Temp(C)  Temp(F)";
	  #print "-----------------------------------";
        }
                COLOR="green";
        } 

        {
                 # $2 is the temp in Celsius, $1 is the device
                 if ( $2 >= CPUHIGHPANIC ) {

                         COLOR="red";
                         print GRED,THISH,":",PROG,"reports",$1,"temperature is",$2,"{high panic level is",CPUHIGHPANIC,"}" >>REDL;

                       } else if ( $2 >= CPUHIGHWARN ) {

                               if (COLOR != "red")
                                       COLOR="yellow";
                               print GYEL,THISH,":",PROG,"reports",$1,"temperature is",$2,"{high warning level is",CPUHIGHWARN,"}" >>YELL;

                       }
        } 
        END { } ' 

      #####
      #####  Now Check for Over-temperature on Sun Fire V1xx and Ultra 25
      #####

      case $MACHINETYPE in
          Sun-Fire-V1xx)
            BAD_OT=`$AWK '/^System Over-temperature Sensors/, /^ 1/ {print $0}' $PRTFILE |
                    $TAIL +2 |
                    $EGREP -v '(ok)'`
              ;;

          A70)
            BAD_OT=`$AWK '/^Temperature sensors:/, /^$/ {print $0}' $PRTFILE |
                    $EGREP -v 'Temperature|  okay|Location|---'`
              ;;

	  Sun-Fire-T200)
            BAD_OT=`$AWK '/^Temperature sensors:/, /^$/ {print $0}' $PRTFILE |
                    $EGREP -v 'Temperature|  ok|Location|---'`
              ;;

          Sun-Fire-V2[14]0)
            BAD_OT=`$EGREP  'T_CORE|T_ENC|FF_OT' $PRTFILE |
                      $GREP -v "okay"`
              ;;


      esac

      if [ ! -z "$BAD_OT" ]; then
            COLOR="red"
            echo "${RED_PIC} prtdiag reports over-temperature !!!" >> $REDLINE
            echo "prtdiag reports over-temperature !!!" >> $REDLINE
            echo "$BAD_OT" >> $REDLINE
      fi

} # process_temp_data()



check_power_supplies()
{
  #####
  #####  Now check for Power Supplies
  #####
  case $MACHINETYPE in
          Netra-T12)
               PS_CHECK=`$CAT $PRTFILE | $GREP "^PS" | $GREP "fault"`
              ;;
          Sun-Fire-V440)
               PS_CHECK=`$CAT $PRTFILE | $GREP "FRU Operational Status"`
              ;;
          Sun-Fire-T200)
               PS_CHECK=`$CAT $PRTFILE | $GREP "FRU Status"`
              ;;

          *)
               PS_CHECK=`$CAT $PRTFILE | $GREP "Power Supplies" `
              ;;
  esac

  if [ ! -z "$PS_CHECK" ]; then
      case $MACHINETYPE in
          Sun-Fire-*8[89]0)
            BAD_PS=`$AWK '/Power Supplies:/, /^===/ {print $0}' $PRTFILE |
                    $GREP -v "^$" |
                    $GREP -v "^==" |
                    $TAIL +5 |
                    $EGREP -v '(GOOD|UNPLUGGED)' `
              ;;
          Sun-Fire)
            BAD_PS=`$AWK '/Power Supplies:/, /^===/ {print $0}' $PRTFILE |
                    $TAIL -4 |
                    $EGREP -v '(^$|^==|FRU|---|Green)' `
              ;;
          Ultra-250)
            BAD_PS=`$AWK '/Power Supplies:/, /^===/ {print $0}' $PRTFILE |
                    $TAIL -5 |
                    $EGREP -v '(^$|^==|---|OK|^Supply)' `
              ;;
          Sun-Fire-V1xx)
            BAD_PS=`$AWK '/PSUs:/, /^1/ {print $0}' $PRTFILE |
	            $TAIL +2 |
                    $EGREP -v '(OK)'` 
              ;;
          Ultra-Enterprise)
            BAD_PS=`$AWK '/Power Supplies:/, /^$/ {print $0}' $PRTFILE |
                    $EGREP -v "(OK|^$|^--|^Sup|^Power)" `
              ;;
          Sun-Fire-480R)
            BAD_PS=`$AWK '/Power Supplies:/, /^===/ {print $0}' $PRTFILE |
                    $TAIL -5 |
                    $EGREP -v '(^$|^==|---|NO_FAULT|^Supply)' `
              ;;
          Sun-Fire-V490)
            BAD_PS=`$AWK '/Power Supplies:/, /^===/ {print $0}' $PRTFILE |
                    $TAIL -5 |
                    $EGREP -v '(^$|^==|---|NO_FAULT|^Supply)' `
              ;;
          Sun-Fire-V440)
            BAD_PS=`$AWK '/Fru Operational/, /^===/ {print $0}' $PRTFILE |
                    $EGREP -v '^$' |
                    $EGREP -v '^==' |
                    $TAIL +6 |
                    $EGREP '^PS' |
                    $EGREP -v "okay"`
              ;;
          Netra-T12)
            BAD_PS=`$GREP "^PS" $PRTFILE |
                    $GREP "fault" |
                    $GREP "ON"`
              ;;
          # FSC PrimePower 200 and 400
          GPUS)
            BAD_PS=`$AWK '/Power Supplies:/, /^$/ {print $0}' $PRTFILE |
                    $EGREP -v -e "^$|Fans:" |
                    $TAIL +1 |
                    $GREP -v "OK" `
              ;;
	  Sun-Fire-T200)
            BAD_PS=`$GREP "^PS" $PRTFILE |
                    $GREP -v "enabled"`
              ;;

          *)
            BAD_PS=`$AWK '/Power Supplies:/, /^$/ {print $0}' $PRTFILE |
                    $GREP -v "^$" |
                    $TAIL +5 |
                    $EGREP -v '(OK|NO_FAULT|Green)' `
              ;;
      esac

      if [ ! -z "$BAD_PS" ]; then
          COLOR="red"
          echo "${RED_PIC} prtdiag reports power supply problems !!!" >> $REDLINE
          echo "prtdiag reports power supply problems !!!" >> $REDLINE
          echo "$BAD_PS" >> $REDLINE
      fi
  fi
}

check_voltage()
{
  #####
  #####  Now Check for Voltages
  #####

  case $MACHINETYPE in
          Netra-T12)
               VOL_CHECK=`$CAT $PRTFILE | $GREP "v_"`
              ;;
          Sun-Fire-V[24]40)
               VOL_CHECK=`$CAT $PRTFILE | $GREP "Voltage sensors"`
              ;;
          Sun-Fire-T200)
               VOL_CHECK=`$CAT $PRTFILE | $GREP "Voltage sensors"`
              ;;

          *)
               VOL_CHECK=`$CAT $PRTFILE | $GREP "Supply voltages" `
              ;;
  esac

  if [ ! -z "$VOL_CHECK" ]; then
    case $MACHINETYPE in
          Sun-Fire-V1xx)
            BAD_VOL=`$AWK '/^Supply voltages:/, /^System status flags/ \
				{if ($0 ~ /^ /) print $0}' $PRTFILE |
                     $GREP -v '(ok)'`
              ;;

          Sun-Fire-V[24]40)
            BAD_VOL=`$EGREP "V_|P_|FF_" $PRTFILE |
                     $GREP -v "okay"`
              ;;

          Netra-T12)
            BAD_VOL=`$GREP "v_" $PRTFILE |
                     $GREP -v "okay"`
              ;;

          Sun-Fire-T200)
            BAD_VOL=`$GREP "V_" $PRTFILE |
                     $GREP -v '  ok'`
              ;;

    esac

    if [ ! -z "$BAD_VOL" ]; then
              COLOR="red"
              echo "${RED_PIC} prtdiag reports voltage problems !!!" >> $REDLINE
              echo "prtdiag reports voltage problems !!!" >> $REDLINE
              echo "$BAD_VOL" >> $REDLINE
    fi

  fi
}

check_current_sensors()
{
  #####
  #####  Now Check for Current Sensors
  #####

  case $MACHINETYPE in
          Sun-Fire-T200)
               CUR_SEN_CHECK=`$CAT $PRTFILE | $GREP "Current sensors"`
              ;;
          *)
               CUR_SEN_CHECK=`$CAT $PRTFILE | $GREP "Current sensors" `
              ;;
  esac

  if [ ! -z "$CUR_SEN_CHECK" ]; then
    case $MACHINETYPE in
          Sun-Fire-T200)
            BAD_CUR_SEN=`$AWK '/^Current sensors:/, /^Current indicators/ \
                                {if ($0 ~ /^ /) print $0}' $PRTFILE |
                     $EGREP -v '(ok)'`
              ;;

    esac

    if [ ! -z "$BAD_CUR_SEN" ]; then
              COLOR="red"
              echo "${RED_PIC} prtdiag reports current sensor problems !!!" >> $REDLINE
              echo "prtdiag reports current sensor problems !!!" >> $REDLINE
              echo "$BAD_CUR_SEN" >> $REDLINE
    fi

  fi
}

check_current_indicators()
{
  #####
  #####  Now Check for Current Indicators
  #####

  case $MACHINETYPE in
          Sun-Fire-T200)
               CUR_IND_CHECK=`$CAT $PRTFILE | $GREP "Current indicators"`
              ;;
          *)
               CUR_IND_CHECK=`$CAT $PRTFILE | $GREP "Current indicators" `
              ;;
  esac

  if [ ! -z "$CUR_IND_CHECK" ]; then
    case $MACHINETYPE in
          Sun-Fire-T200)
            BAD_CUR_IND=`$AWK '/^Current indicators:/, /^Voltage sensors/ \
                                {if ($0 ~ /^ /) print $0}' $PRTFILE |
                     $EGREP -v '(ok)'`
              ;;

    esac

    if [ ! -z "$BAD_CUR_IND" ]; then
              COLOR="red"
              echo "${RED_PIC} prtdiag reports current indicator problems !!!" >> $REDLINE
              echo "prtdiag reports current indicator problems !!!" >> $REDLINE
              echo "$BAD_CUR_IND" >> $REDLINE
    fi

  fi
}

clean_up_our_mess ()
{
  # Clean up our mess
  # Checking for existence of files since the whole test may be optional
  #   and may not actually run on every client
  #
  if [ -f $BBTMP/$MACHINE.$TEST ]; then
    $RM $BBTMP/$MACHINE.$TEST
    $RM $PRTFILE $YELLOWLINE $REDLINE
  fi

  if [ -f $LEDFILE_FIRSTROW ]; then
    $RM $LEDFILE_FIRSTROW
  fi

  if [ -f $LEDFILE_SECONDROW ]; then
    $RM $LEDFILE_SECONDROW
  fi

  if [ -f $LEDFILE_LASTROW ]; then
    $RM $LEDFILE_LASTROW
  fi

}

#####
#####  Main body
#####

if [ "$CHECK_BB_HOSTS" = "Y" ]; then
  # convert "," to "." in the hostname
  MACHINE_WITH_DOTS=`echo $MACHINE | $SED 's/,/\./g'`

  $GREP $MACHINE_WITH_DOTS $BBHOSTS | $GREP "$TEST" |
  while read line
  do
    if [ ! -z "$line" ]; then
      #echo "" > $YELLOWLINE
      #echo "" > $REDLINE
      $CP /dev/null $YELLOWLINE
      $CP /dev/null $REDLINE
      get_status > $BBTMP/$MACHINE.$TEST

      # COLOR for the whole page was not being set correctly, if Temperature is bad
      if [ -s "$YELLOWLINE" ]; then
        COLOR="yellow"
      fi

      if [ -s "$REDLINE" ]; then
        COLOR="red"
      fi

      # NOW USE THE BB COMMAND TO SEND THE DATA ACROSS
      $BB $BBDISP "status $MACHINE.$TEST $COLOR `$DATE` `$CAT $REDLINE` `$CAT $YELLOWLINE` `$CAT $BBTMP/$MACHINE.$TEST` "
    fi
  done
else
  #echo "" > $YELLOWLINE
  #echo "" > $REDLINE
  $CP /dev/null $YELLOWLINE
  $CP /dev/null $REDLINE
  get_status > $BBTMP/$MACHINE.$TEST

  # COLOR for the whole page was not being set correctly, if Temperature is bad
  if [ -s "$YELLOWLINE" ]; then
    COLOR="yellow"
  fi

  if [ -s "$REDLINE" ]; then
    COLOR="red"
  fi

  # NOW USE THE BB COMMAND TO SEND THE DATA ACROSS
  $BB $BBDISP "status $MACHINE.$TEST $COLOR `$DATE` `$CAT $REDLINE` `$CAT $YELLOWLINE` `$CAT $BBTMP/$MACHINE.$TEST` "
fi

if [ "$DEBUG" != "Y" ]; then
  clean_up_our_mess
fi

##############################################
# end of script
##############################################
